# NuRadioMC
A Monte Carlo simulation package for radio neutrino detectors

Please visit the wiki at https://github.com/nu-radio/NuRadioMC/wiki for documentation.

If you're using NuRadioMC for your research, please cite

C. Glaser, D. Garcia-Fernandez, A. Nelles et al., "NuRadioMC: Simulating the radio emission of neutrinos from interaction to detector", submitted to Eur. Phys. J. C, arXiv:1906.01670

and

C. Glaser, A. Nelles, I. Plaisier, C. Welling et al., "NuRadioReco: A reconstruction framework for radio neutrino detectors", Eur. Phys. J. C (2019) 79: 464, doi:10.1140/epjc/s10052-019-6971-5, arXiv:1903.07023

for the detector simulation part. 

If you would like to contribute, please contact @cg-laser or @anelles for permissions to work on NuRadioMC. We work with pull requests only that can be merged after review. 
